==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/architecture/interfaces/Message.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.interfaces.Iface;
import io.ciera.tool.sql.architecture.interfaces.PortMessage;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;


public interface Message extends IModelInstance<Message,Sql> {

    // attributes
    public String getIface_name() throws XtumlException;
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public String getIface_package() throws XtumlException;
    public String getName() throws XtumlException;
    public void setName( String m_name ) throws XtumlException;
    public void setTo_provider( boolean m_to_provider ) throws XtumlException;
    public boolean getTo_provider() throws XtumlException;
    public int getId() throws XtumlException;
    public void setId( int m_id ) throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR419_defines_message_format_for_Iface( Iface inst ) {}
    public Iface R419_defines_message_format_for_Iface() throws XtumlException;
    default public void addR420_is_implemented_within_PortMessage( PortMessage inst ) {}
    default public void removeR420_is_implemented_within_PortMessage( PortMessage inst ) {}
    public PortMessageSet R420_is_implemented_within_PortMessage() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/interfaces/Message.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.interfaces.Iface;
import io.ciera.tool.sql.architecture.interfaces.PortMessage;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.ooaofooa.component.ExecutableProperty;


public interface Message extends IModelInstance<Message,Sql> {

    // attributes
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public String getIface_name() throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public String getIface_package() throws XtumlException;
    public void setName( String m_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public boolean getTo_provider() throws XtumlException;
    public void setTo_provider( boolean m_to_provider ) throws XtumlException;
    public void setId( int m_id ) throws XtumlException;
    public int getId() throws XtumlException;


    // operations
    public void render() throws XtumlException;


    // selections
    default public void setR419_defines_message_format_for_Iface( Iface inst ) {}
    public Iface R419_defines_message_format_for_Iface() throws XtumlException;
    default public void addR420_is_implemented_within_PortMessage( PortMessage inst ) {}
    default public void removeR420_is_implemented_within_PortMessage( PortMessage inst ) {}
    public PortMessageSet R420_is_implemented_within_PortMessage() throws XtumlException;
    default public void setR4761_ExecutableProperty( ExecutableProperty inst ) {}
    public ExecutableProperty R4761_ExecutableProperty() throws XtumlException;


}
